summaryrefslogtreecommitdiffstats
path: root/generic/tclUtil.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclUtil.c')
-rw-r--r--generic/tclUtil.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/generic/tclUtil.c b/generic/tclUtil.c
index f7f4bf4..3b5b527 100644
--- a/generic/tclUtil.c
+++ b/generic/tclUtil.c
@@ -1786,7 +1786,7 @@ Tcl_ConcatObj(
/*
* Tcl_ListObjAppendList could be used here, but this saves us a
* bit of type checking (since we've already done it). Use of
* INT_MAX tells us to always put the new stuff on the end. It
* will be set right in Tcl_ListObjReplace.
* Note that all objs at this point are either lists or have an
* empty string rep.
@@ -1799,7 +1799,7 @@ Tcl_ConcatObj(
TclListObjGetElements(NULL, objPtr, &listc, &listv);
if (listc) {
if (resPtr) {
- Tcl_ListObjReplace(NULL, resPtr, INT_MAX, 0, listc, listv);
+ Tcl_ListObjReplace(NULL, resPtr, LIST_MAX, 0, listc, listv);
} else {
resPtr = TclListObjCopy(NULL, objPtr);
}
@@ -1786,7 +1786,7 @@ Tcl_ConcatObj(
* Tcl_ListObjAppendList could be used here, but this saves us a
* bit of type checking (since we've already done it). Use of
- * INT_MAX tells us to always put the new stuff on the end. It
+ * LIST_MAX tells us to always put the new stuff on the end. It
* will be set right in Tcl_ListObjReplace.
* Note that all objs at this point are either lists or have an